# Changelog

## v1.3.0 - 2026-03-25

- Maintenance release.

## v1.2.11 - 2026-03-25

### Other
- Remove commit validation; update CHRONICLE
- Merge branch 'main' of https://github.com/CptPlastic/lore-book
- Add PyPI publish job and CHRONICLE notes

## v1.2.10 - 2026-03-25

### Documentation
- add demo/overview presentation page

### Other
- Merge branch 'main' of https://github.com/CptPlastic/lore-book
- Add CHRONICLE sync & automated releases
- Add demo slide deck (site/demo.html)

